### Name: betaper
### Title: Distance decay of similarity among floristic inventories in the
###   face of taxonomic uncertainty
### Aliases: betaper print.betaper
### Keywords: multivariate htest

### ** Examples

## Not run: 
##D require(vegan)
##D ################################################
##D # Tree data from 16 0.1-ha plots from the Highlands of Chiapas, southern Mexico
##D 
##D data(HCP)
##D data(HCP.coords)
##D 
##D geodist.HCP <- dist(HCP.coords)/1000    # Geographical distances in kms
##D 
##D # Define a new index that includes the terms used in the HCP dataset to define undetermined taxa at genus and family levels
##D index.new <- c(paste("Genus", as.character(c(1:20)), sep=""), paste("Family", as.character(c(1:20)), sep=""))
##D 
##D beta.HCP <- betaper(HCP, geodist = geodist.HCP, index = index.new)
##D beta.HCP        # This results in a relatively low uncertainty range of the estimated correlation
##D beta.HCP$taxunc # Number of identified and unidentified species at different taxonomic levels
##D 
##D ################################################
##D # Tree data from nine lowland sites in Western Amazonia
##D 
##D data(Amazonia)
##D data(soils)
##D 
##D # Define a new index that includes the terms used in the Amazonia dataset to define undetermined taxa at different taxonomic levels
##D index.Amazon <- c(paste("sp.", rep(1:20), sep=""), "Indet.", "indet.")
##D 
##D beta.Amazonia <- betaper(Amazonia, geodist = dist(log(soils)), index = index.Amazon, nsim = 50) # This can take a few minutes
##D beta.Amazonia   # The uncertainty range of the estimated correlation is much larger than in the previous example
##D beta.Amazonia$taxunc    # Number of identified and unidentified species at different taxonomic levels
## End(Not run)



